![](https://img.shields.io/badge/python-3.10-orange) ![](https://img.shields.io/badge/status-in_progress-red)
# Cambrian Tools 🔧

## Installation
To install the package run the following script:
```bash
pip install cambriantools
```

## How to use
To execute [master_run.sh](master_run.sh) just run the following command in the terminal:
```bash
bash master_run.sh
```

## Data
Public data: https://drive.google.com/drive/folders/19q3OVxoATB-UaoIsvjp07su9Uy2XJQnT?usp=sharing

## References
- https://github.com/oscarpimentel/fuzzy-tools